<?php 
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants and as for required function files.
 * ----------------------------------------------------------------------------------------
 */
define( 'THEMEROOT', get_stylesheet_directory_uri() );
define( 'IMAGES', THEMEROOT . '/images' );
define( 'SCRIPTS', THEMEROOT . '/js' );
define( 'FRAMEWORK', get_template_directory() . '/framework' );


/* Theme Option */

add_filter( 'ot_show_pages', '__return_false' );
add_filter( 'ot_show_new_layout', '__return_false' );
add_filter( 'ot_theme_mode', '__return_true' );
include_once( 'option-tree/ot-loader.php' );
include_once('inc/theme-options.php');


/**
 * ----------------------------------------------------------------------------------------
 * 2.0 - Load the framework.
 * ----------------------------------------------------------------------------------------
 */
/* require_once( FRAMEWORK . '/init.php' ); */


/**
 * ----------------------------------------------------------------------------------------
 * 3.0 - Set up the content width value based on the theme's design.
 * ----------------------------------------------------------------------------------------
 */
if ( ! isset( $content_width ) ) {
	$content_width = 800;
}


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'dd_setup' ) ) {
	function dd_setup() {
		/**
		 * Make the theme available for translation.
		 */
		$lang_dir = THEMEROOT . '/languages';
		load_theme_textdomain( 'dd', $lang_dir );

		/**
		 * Add support for automatic feed links.
		 */
		add_theme_support( 'automatic-feed-links' );

		/**
		 * Add support for post excerpts
		 */

			function new_excerpt_more( $more ) {
				return ' <a class="readmore" href="'. get_permalink( get_the_ID() ) . '">' . __('Read More', 'dd') . '</a>';
			}
			add_filter( 'excerpt_more', 'new_excerpt_more' );

		/**
		 * Add support for post thumbnails.
		 */
		add_theme_support( 'post-thumbnails' );
		/* 
			/* Add Support for homepage single post image sizes
		*/
		add_image_size( 'post-image', 225, 225, true );
		
		
		/**
		 * Register nav menus.
		 */
		register_nav_menus(
			array(
				'main-menu' => __( 'Main Menu', 'dd' )
			)
		);
	}

	add_action( 'after_setup_theme', 'dd_setup' );
}


/**
 * ----------------------------------------------------------------------------------------
 * 5.0 - Display meta information for a specific post.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'dd_post_meta' ) ) {
	function dd_post_meta() {
		echo '<ul class="list-inline entry-meta">';

		if ( get_post_type() === 'post' ) {
			// If the post is sticky, mark it.
			if ( is_sticky() ) {
				echo '<li class="meta-featured-post"><i class="fa fa-thumb-tack"></i> ' . __( 'Sticky', 'dd' ) . ' </li>';
			}

			// Get the post author.
			printf(
				'<li class="meta-author"><a href="%1$s" rel="author">%2$s</a></li>',
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				get_the_author()
			);

			// Get the date.
			echo '<li class="meta-date"> ' . get_the_date() . ' </li>';

			// The categories.
			$category_list = get_the_category_list( ', ' );
			if ( $category_list ) {
				echo '<li class="meta-categories"> ' . $category_list . ' </li>';
			}

			// The tags.
			$tag_list = get_the_tag_list( '', ', ' );
			if ( $tag_list ) {
				echo '<li class="meta-tags"> ' . $tag_list . ' </li>';
			}

			// Comments link.
			if ( comments_open() ) :
				echo '<li>';
				echo '<span class="meta-reply">';
				comments_popup_link( __( 'Leave a comment', 'dd' ), __( 'One comment so far', 'dd' ), __( 'View all % comments', 'dd' ) );
				echo '</span>';
				echo '</li>';
			endif;

			// Edit link.
			if ( is_user_logged_in() ) {
				echo '<li>';
				edit_post_link( __( 'Edit', 'dd' ), '<span class="meta-edit">', '</span>' );
				echo '</li>';
			}
		}
	}
}


/**
 * ----------------------------------------------------------------------------------------
 * 6.0 - Display navigation to the next/previous set of posts.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'dd_paging_nav' ) ) {
	function dd_paging_nav() { ?>
		<ul class="dd_pagination">
			<?php 
				if ( get_previous_posts_link() ) : ?>
				<li class="next">
					<?php previous_posts_link( __( 'Newer Posts &rarr;', 'dd' ) ); ?>
				</li>
				<?php endif;
			 ?>
			<?php 
				if ( get_next_posts_link() ) : ?>
				<li class="previous">
					<?php next_posts_link( __( '&larr; Older Posts', 'dd' ) ); ?>
				</li>
				<?php endif;
			 ?>
		</ul> <?php
	}
}


/**
 * ----------------------------------------------------------------------------------------
 * 7.0 - Register the widget areas.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'dd_widget_init' ) ) {
	function dd_widget_init() {
		if ( function_exists( 'register_sidebar' ) ) {
			register_sidebar(
				array(
					'name' => __( 'Main Widget Area', 'dd' ),
					'id' => 'sidebar-1',
					'description' => __( 'Appears on posts and pages.', 'dd' ),
					'before_widget' => '<div id="%1$s" class="single_sidebar %2$s">',
					'after_widget' => '</div> <!-- end widget -->',
					'before_title' => '<h2>',
					'after_title' => '</h2>',
				)
			);
		}
	}

	add_action( 'widgets_init', 'dd_widget_init' );
}

/**
 * ----------------------------------------------------------------------------------------
 * 8.0 - Function that validates a field's length.
 * ----------------------------------------------------------------------------------------
 */
if ( ! function_exists( 'dd_validate_length' ) ) {
	function dd_validate_length( $fieldValue, $minLength ) {
		// First, remove trailing and leading whitespace
		return ( strlen( trim( $fieldValue ) ) > $minLength );
	}
}


 
 
 
 
 
/**
 * ----------------------------------------------------------------------------------------
 * 9 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
 
/* Add Editor Style */



 
if ( ! function_exists( 'dd_scripts' ) ) {
	function dd_scripts() {
		// Adds support for pages with threaded comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Register scripts
		wp_register_script( 'dd-bootstrap', SCRIPTS . '/bootstrap.min.js', array( 'jquery' ), false, true );
		wp_register_script( 'dd-uikit', SCRIPTS . '/uikit.min.js', array( 'jquery' ), false, true );

		// Load the custom scripts
		wp_enqueue_script( 'dd-bootstrap' );
		wp_enqueue_script( 'dd-uikit' );

		// Load the stylesheets
		
		add_editor_style();
		wp_enqueue_style( 'font-awesome', THEMEROOT . '/font-awesome/css/font-awesome.min.css' );
		wp_enqueue_style( 'dd-master', THEMEROOT . '/css/master.css' );
		wp_enqueue_style( 'dd-style', get_stylesheet_uri() );
		
		
	}

	add_action( 'wp_enqueue_scripts', 'dd_scripts' );
}
?>