<?php
/**
 * Initialize the options before anything else. 
 */
add_action( 'admin_init', '_custom_theme_options', 1 );

/**
 * Theme Mode demo code of all the available option types.
 *
 * @return    void
 *
 * @access    private
 * @since     2.0
 */
function _custom_theme_options() {
  
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Create a custom settings array that we pass to 
   * the OptionTree Settings API Class.
   */
  $custom_settings = array(
    'contextual_help' => array(
      'content'       => array( 
        array(
          'id'        => 'general_help',
          'title'     => 'General',
          'content'   => '<p>You can use the following panel to edit several options in your theme.</p>'
        )
      ),
      'sidebar'       => '<p></p>'
    ),
    'sections'        => array(
      array(
        'title'       => 'General',
        'id'          => 'general_default'
      ),
      array(
        'title'       => 'Social',
        'id'          => 'social'
      ),
      array(
        'title'       => 'Footer',
        'id'          => 'footer'
      )
    ),
    'settings'        => array(
      array(
	  /* General Settings */
      
		'label'       => 'Site Logo',
        'id'          => 'logo_upload',
        'type'        => 'upload',
        'desc'        => 'If you want to upload a logo, simply upload it here and save it. If want to show your site\'s title as the header, leave it empty.',
        'section'     => 'general_default'
      ),
	  
	  /* Social Settings */
	  array(
        'label'       => 'Facebook',
        'id'          => 'facebook',
        'type'        => 'text',
        'desc'        => 'Paste your Facebook url here. Please, include HTTP:// ',
        'section'     => 'social'
      ),
	  array(
        'label'       => 'Twitter',
        'id'          => 'twitter',
        'type'        => 'text',
        'desc'        => 'Paste your Twitter url here. Please, include HTTP:// ',
        'section'     => 'social'
      ),
	  array(
        'label'       => 'Youtube',
        'id'          => 'youtube',
        'type'        => 'text',
        'desc'        => 'Paste your Youtube url here. Please, include HTTP:// ',
        'section'     => 'social'
      ),
	  array(
        'label'       => 'Google Plus',
        'id'          => 'google_plus',
        'type'        => 'text',
        'desc'        => 'Paste your Google Plus url here. Please, include HTTP:// ',
        'section'     => 'social'
      )
	  /* Single */
	  ,
	   array(
        'id'          => 'credit_on_off',
        'label'       => 'On/Off Credit Link',
        'desc'        => 'You can turn on/off credit link section', '<code>on</code>', '<code>off</code>',
        'std'         => '',
        'type'        => 'on-off',
        'section'     => 'footer'
      )
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}